@@ -5,6 +5,7 @@ import logging
 import construct
 import binascii
 from typing import Any, List, Optional  # noqa: F401
+from enum import Enum
 
 from .protocol import Message
 
@@ -21,6 +22,13 @@ class DeviceError(DeviceException):
     pass
 
 
+class UpdateState(Enum):
+    Downloading = "downloading"
+    Installing = "installing"
+    Failed = "failed"
+    Idle = "idle"
+
+
 class DeviceInfo:
     """Container of miIO device information.
     Hardware properties such as device model, MAC address, memory information,
@@ -87,6 +95,13 @@ class DeviceInfo:
             return self.data["hw_ver"]
         return None
 
+    @property
+    def mac_address(self) -> Optional[str]:
+        """MAC address if available."""
+        if self.data["mac"] is not None:
+            return self.data["mac"]
+        return None
+
     @property
     def raw(self):
         """Raw data as returned by the device."""
@@ -264,13 +279,14 @@ class Device:
                                   "of an invalid token. "
                                   "Please check your token!") from ex
         except OSError as ex:
-            _LOGGER.error("Got error when receiving: %s", ex)
             if retry_count > 0:
-                _LOGGER.warning("Retrying with incremented id, "
-                                "retries left: %s", retry_count)
+                _LOGGER.debug("Retrying with incremented id, "
+                              "retries left: %s", retry_count)
                 self.__id += 100
                 self._discovered = False
                 return self.send(command, parameters, retry_count - 1)
+
+            _LOGGER.error("Got error when receiving: %s", ex)
             raise DeviceException("No response from the device") from ex
 
     def raw_command(self, cmd, params):
@@ -288,6 +304,34 @@ class Device:
         and harware and software versions."""
         return DeviceInfo(self.send("miIO.info", []))
 
+    def update(self, url: str, md5: str):
+        """Start an OTA update."""
+        payload = {
+            "mode": "normal",
+            "install": "1",
+            "app_url": url,
+            "file_md5": md5,
+            "proc": "dnld install"
+        }
+        return self.send("miIO.ota", payload)[0] == "ok"
+
+    def update_progress(self) -> int:
+        """Return current update progress [0-100]."""
+        return self.send("miIO.get_ota_progress", [])[0]
+
+    def update_state(self):
+        """Return current update state."""
+        return UpdateState(self.send("miIO.get_ota_state", [])[0])
+
+    def configure_wifi(self, ssid, password, uid=0, extra_params=None):
+        """Configure the wifi settings."""
+        if extra_params is None:
+            extra_params = {}
+        params = {"ssid": ssid, "passwd": password, "uid": uid,
+                  **extra_params}
+
+        return self.send("miIO.config_router", params)[0]
+
     @property
     def _id(self) -> int:
         """Increment and return the sequence id."""
