@@ -20,10 +20,8 @@ from pprint import pprint as pp  # noqa: F401
 
 from construct import (Struct, Bytes, Const, Int16ub, Int32ub, GreedyBytes,
                        Adapter, Checksum, RawCopy, Rebuild, IfThenElse,
-                       Default, Pointer, Hex)
-
-# for debugging parsing
-# from construct import Probe
+                       Default, Pointer, Hex, Probe)
+import construct
 
 from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
 from cryptography.hazmat.backends import default_backend
@@ -31,6 +29,9 @@ from cryptography.hazmat.primitives import padding
 
 _LOGGER = logging.getLogger(__name__)
 
+# needs to be maintained in sync with setup.py and requirements.txt
+assert construct.version_string == "2.9.31"
+
 
 class Utils:
     """ This class is adapted from the original xpn.py code by gst666 """
@@ -130,16 +131,16 @@ class Utils:
 
 class TimeAdapter(Adapter):
     """Adapter for timestamp conversion."""
-    def _encode(self, obj, context, *args, **kwargs):
+    def _encode(self, obj, context, path):
         return calendar.timegm(obj.timetuple())
 
-    def _decode(self, obj, context, *args, **kwargs):
+    def _decode(self, obj, context, path):
         return datetime.datetime.utcfromtimestamp(obj)
 
 
 class EncryptionAdapter(Adapter):
     """Adapter to handle communication encryption."""
-    def _encode(self, obj, context, *args, **kwargs):
+    def _encode(self, obj, context, path):
         """Encrypt the given payload with the token stored in the context.
 
         :param obj: JSON object to encrypt"""
@@ -147,7 +148,7 @@ class EncryptionAdapter(Adapter):
         return Utils.encrypt(json.dumps(obj).encode('utf-8') + b'\x00',
                              context['_']['token'])
 
-    def _decode(self, obj, context, *args, **kwargs):
+    def _decode(self, obj, context, path):
         """Decrypts the given payload with the token stored in the context.
 
         :return str: JSON object"""
@@ -159,17 +160,32 @@ class EncryptionAdapter(Adapter):
             _LOGGER.debug("Unable to decrypt, returning raw bytes: %s", obj)
             return obj
 
-        decoded = decrypted.decode('utf-8')
-        try:
-            return json.loads(decoded)
-        except:
+        # list of adaption functions for malformed json payload (quirks)
+        decrypted_quirks = [
+            # try without modifications first
+            lambda decrypted_bytes: decrypted_bytes,
+            # powerstrip returns malformed JSON if the device is not
+            # connected to the cloud, so we try to fix it here carefully.
+            lambda decrypted_bytes: decrypted_bytes.replace(b',,"otu_stat"', b',"otu_stat"'),
+            # xiaomi cloud returns malformed json when answering _sync.batch_gen_room_up_url
+            # command so try to sanitize it
+            lambda decrypted_bytes:
+                decrypted_bytes[:decrypted_bytes.rfind(b'\x00')]
+                if b'\x00' in decrypted_bytes
+                else decrypted_bytes
+        ]
+
+        for i, quirk in enumerate(decrypted_quirks):
+            decoded = quirk(decrypted).decode('utf-8')
             try:
-                # powerstrip returns invalid JSON if the device is not
-                # connected to the cloud, so we try to fix it here carefully.
-                decoded = decoded.replace(',,"otu_stat"', ',"otu_stat"')
                 return json.loads(decoded)
             except Exception as ex:
-                _LOGGER.error("unable to parse json '%s': %s", decoded, ex)
+                # log the error when decrypted bytes couldn't be loaded
+                # after trying all quirk adaptions
+                if i == len(decrypted_quirks) - 1:
+                    _LOGGER.error("unable to parse json '%s': %s", decoded, ex)
+
+        return None
 
 
 Message = Struct(
