@@ -7,7 +7,8 @@ import datetime
 import pytz
 
 from .vacuumcontainers import (VacuumStatus, ConsumableStatus, DNDStatus,
-                               CleaningSummary, CleaningDetails, Timer)
+                               CleaningSummary, CleaningDetails, Timer,
+                               SoundStatus, SoundInstallStatus)
 from .device import Device, DeviceException
 
 _LOGGER = logging.getLogger(__name__)
@@ -214,7 +215,32 @@ class Vacuum(Device):
 
     def sound_info(self):
         """Get voice settings."""
-        return self.send("get_current_sound")
+        return SoundStatus(self.send("get_current_sound")[0])
+
+    def install_sound(self, url: str, md5sum: str, sound_id: int):
+        """Install sound from the given url."""
+        payload = {
+            "url": url,
+            "md5": md5sum,
+            "sid": int(sound_id),
+        }
+        return SoundInstallStatus(self.send("dnld_install_sound", payload)[0])
+
+    def sound_install_progress(self):
+        """Get sound installation progress."""
+        return SoundInstallStatus(self.send("get_sound_progress")[0])
+
+    def sound_volume(self) -> int:
+        """Get sound volume."""
+        return self.send("get_sound_volume")[0]
+
+    def set_sound_volume(self, vol: int):
+        """Set sound volume [0-100]."""
+        return self.send("change_sound_volume", [vol])
+
+    def test_sound_volume(self):
+        """Test current sound volume."""
+        return self.send("test_sound_volume")
 
     def serial_number(self):
         """Get serial number."""
@@ -230,14 +256,14 @@ class Vacuum(Device):
 
     def configure_wifi(self, ssid, password, uid=0, timezone=None):
         """Configure the wifi settings."""
-        params = {"ssid": ssid, "passwd": password, "uid": uid}
+        extra_params = {}
         if timezone is not None:
             now = datetime.datetime.now(pytz.timezone(timezone))
             offset_as_float = now.utcoffset().total_seconds() / 60 / 60
-            params["tz"] = timezone
-            params["gmt_offset"] = offset_as_float
+            extra_params["tz"] = timezone
+            extra_params["gmt_offset"] = offset_as_float
 
-        return self.send("miIO.config_router", params)[0]
+        return super().configure_wifi(ssid, password, uid, extra_params)
 
     def raw_command(self, cmd, params):
         """Send a raw command to the robot."""
